% Prep data for Stage 1 estimation

%clear all
load matdata

numtype = 3; % number of types for unobserved heterogeneity

%set bandwidth for shares.
band = 0.55 % base bandwidth
lambda = 0.55 % adaptive bandwidth parameter.

neigh = unique(ztract); year=(unique(zyear));
nobs = length(ztract); T = length(unique(zyear));
 
% number of tracts
J = length(neigh);

%what neighborhood number is everyone in
%nhood runs 1,2,...,J.  ztract is the actual supertract numbers
nhood = zeros(nobs,1);
for i= 1:nobs
    nhood(i) = find(neigh==ztract(i));
end

ind = ismember(neigh_county_map(:,1),neigh);
neigh_county_map = neigh_county_map(ind,:); % get neigh-to-county mapping only for supertracts used.

for i= 1:length(neigh_county_map)
   neigh_county_map(i,3) = find(neigh==neigh_county_map(i,1));
end
neigh_county_map = [neigh_county_map; max(neigh_county_map)+1];

countyi = neigh_county_map(nhood,2);
countyj = neigh_county_map(:,2);

% 1 (SF):  San Francisco County, Marin County, San Mateo County
% 2 (South Bay):  Santa Clara County
% 3 (East Bay): Alameda County, Contra Costa County
% define geography 
typei = 1*[countyi == 41 | countyi == 75 | countyi == 81] + 2*[countyi == 85]  + 3*[countyi == 1 | countyi == 13] ;
typej = 1*[countyj == 41 | countyj == 75 | countyj == 81] + 2*[countyj == 85]  + 3*[countyj == 1 | countyj == 13] ;

%get the tract choice broken out by year
ztract1 = ztract(zyear==year(1));ztract2 = ztract(zyear==year(2));
ztract3 = ztract(zyear==year(3));ztract4 = ztract(zyear==year(4));
ztract5 = ztract(zyear==year(5));ztract6 = ztract(zyear==year(6));
ztract7 = ztract(zyear==year(7));ztract8 = ztract(zyear==year(8));
ztract9 = ztract(zyear==year(9));ztract10 = ztract(zyear==year(10));
ztract11 = ztract(zyear==year(11));

price10 = price/10;%get price in $10,000
wealth=(downp/10);

inc =  (income/10);%get income in $10,000
race = apwhite;

Ztype = [wealth inc];

wealthvalsa = [0:1:24]'; % set values at which we will evaluate types for wealth in S12
wealthvalsb = [0:1:24]'; % set values at which we will evaluate types for wealth in S34
maxw = max(wealthvalsa);minw = min(wealthvalsa);

incvalsa = [0:1:24]';% set values at which we will evaluate types for income in S12
incvalsb = [4 12 20]';% set values at which we will evaluate types for income in S34
maxi = max(incvalsa); mini = min(incvalsa);

M1a= length(wealthvalsa);M2a=length(incvalsa);
Ma=M1a*M2a;% Ma is the total number of types in stages 1/2

M1b= length(wealthvalsb);M2b=length(incvalsb);
Mb=M1b*M2b;% Mb is the total number of types in stages 3/4

%get the Ma values of Z 
Zvalsa = zeros(Ma,3);Zvals1a=[];Zvals2a=[];
for i= 1:M1a
    Zvals2a = [Zvals2a; incvalsa];
end
Zvals1a = kron(wealthvalsa,ones(M2a,1));
Zvalsa = [Zvals1a Zvals2a];

%get the Mb values of Z 
Zvalsb = zeros(Mb,3);Zvals1b=[];Zvals2b=[];
for i= 1:M1b
    Zvals2b = [Zvals2b; incvalsb];
end
Zvals1b = kron(wealthvalsb,ones(M2b,1));
Zvalsb = [Zvals1b Zvals2b];

% get an index to recover S34 types from S12 types
indexb = find(Zvalsa(:,2)== incvalsb(1) | Zvalsa(:,2)== incvalsb(2) | Zvalsa(:,2)== incvalsb(3));
temp = [];
for h = 1:numtype
temp = [temp; (h-1)*Ma+indexb];
end
indexb = temp;

K=size(Zvalsa,2);

% create an indicator to add the utility bump from living in preferred region
indic = zeros(numtype*Ma,J+1,T);
for m=1:Ma
for h = 1:numtype
    indic(m+ (h-1)*Ma,typej==h,:) = 1;
end
end

% get wealth in all future time periods if staying or if moving
Ws = zeros(nobs,T); Wm = zeros(nobs,T);
for i = 1:nobs
    yeari = find(year==zyear(i));
    Ws(i,yeari) = Ztype(i,1);Wm(i,yeari) = Ztype(i,1) - 0.06*price10(i);
    for t=yeari:T
        Ws(i,t) = max(Ztype(i,1)+(price10(i)*((totapp(nhood(i),t)/totapp(nhood(i),yeari))-1)),0);
        Wm(i,t) = max(Ztype(i,1)+(price10(i)*((totapp(nhood(i),t)/totapp(nhood(i),yeari))-1))-0.06*(price10(i)*(totapp(nhood(i),t)/totapp(nhood(i),yeari))),0);
    end
end

outside=(fsyear~=0 & fpyear==0); % one if hh moves at a future date and then chooses outside option
inside=(fsyear~=0 & fpyear~=0); % one if hh moves at a future date and then chooses inside option

out1=(fsyear==year(1));out2=(fsyear==year(2));
out3=(fsyear==year(3));out4=(fsyear==year(4));
out5=(fsyear==year(5));out6=(fsyear==year(6));
out7=(fsyear==year(7));out8=(fsyear==year(8));
out9=(fsyear==year(9));out10=(fsyear==year(10));
out11=(fsyear==year(11)); %one if hh moves at future date year 11. ie, they make an in/out decision in year 11

%get wealth and income for people who make outside/inside choice in each year
wealthout1=zeros(sum(out1),1);incout1=wealthout1;dec1=wealthout1;
j=1;
for i=1:nobs
    if(out1(i)==1)
    wealthout1(j)=Wm(i,fsyear(i)-1993);
    incout1(j)=inc(i);
    dec1(j)=outside(i);
    j=j+1;
    end
end

wealthout2=zeros(sum(out2),1);incout2=wealthout2;dec2=wealthout2;
j=1;
for i=1:nobs
    if(out2(i)==1)
    wealthout2(j)=Wm(i,fsyear(i)-1993);
    incout2(j)=inc(i);
    dec2(j)=outside(i);
    j=j+1;
    end
end

wealthout3=zeros(sum(out3),1);incout3=wealthout3;dec3=wealthout3;
j=1;
for i=1:nobs
    if(out3(i)==1)
    wealthout3(j)=Wm(i,fsyear(i)-1993);
    incout3(j)=inc(i);
    dec3(j)=outside(i);    
    j=j+1;
    end
end

wealthout4=zeros(sum(out4),1);incout4=wealthout4;dec4=wealthout4;
j=1;
for i=1:nobs
    if(out4(i)==1)
    wealthout4(j)=Wm(i,fsyear(i)-1993);
    incout4(j)=inc(i);
    dec4(j)=outside(i);    
    j=j+1;
    end
end

wealthout5=zeros(sum(out5),1);incout5=wealthout5;dec5=wealthout5;
j=1;
for i=1:nobs
    if(out5(i)==1)
    wealthout5(j)=Wm(i,fsyear(i)-1993);
    incout5(j)=inc(i);
    dec5(j)=outside(i);    
    j=j+1;
    end
end

wealthout6=zeros(sum(out6),1);incout6=wealthout6;dec6=wealthout6;
j=1;
for i=1:nobs
    if(out6(i)==1)
    wealthout6(j)=Wm(i,fsyear(i)-1993);
    incout6(j)=inc(i);
    dec6(j)=outside(i);    
    j=j+1;
    end
end

wealthout7=zeros(sum(out7),1);incout7=wealthout7;dec7=wealthout7;
j=1;
for i=1:nobs
    if(out7(i)==1)
    wealthout7(j)=Wm(i,fsyear(i)-1993);
    incout7(j)=inc(i);
    dec7(j)=outside(i);    
    j=j+1;
    end
end

wealthout8=zeros(sum(out8),1);incout8=wealthout8;dec8=wealthout8;
j=1;
for i=1:nobs
    if(out8(i)==1)
    wealthout8(j)=Wm(i,fsyear(i)-1993);
    incout8(j)=inc(i);
    dec8(j)=outside(i);    
    j=j+1;
    end
end

wealthout9=zeros(sum(out9),1);incout9=wealthout9;dec9=wealthout9;
j=1;
for i=1:nobs
    if(out9(i)==1)
    wealthout9(j)=Wm(i,fsyear(i)-1993);
    incout9(j)=inc(i);
    dec9(j)=outside(i);    
    j=j+1;
    end
end

wealthout10=zeros(sum(out10),1);incout10=wealthout10;dec10=wealthout10;
j=1;
for i=1:nobs
    if(out10(i)==1)
    wealthout10(j)=Wm(i,fsyear(i)-1993);
    incout10(j)=inc(i);
    dec10(j)=outside(i);    
    j=j+1;
    end
end

wealthout11=zeros(sum(out11),1);incout11=wealthout11;dec11=wealthout11;
j=1;
for i=1:nobs
    if(out11(i)==1)
    wealthout11(j)=Wm(i,fsyear(i)-1993);
    incout11(j)=inc(i);
    dec11(j)=outside(i);    
    j=j+1;
    end
end

%vector of wealth,income,year for hh making in/out choice
wealthall=[wealthout1;wealthout2;wealthout3;wealthout4;wealthout5;wealthout6;wealthout7;wealthout8;wealthout9;wealthout10;wealthout11];
incall=[incout1;incout2;incout3;incout4;incout5;incout6;incout7;incout8;incout9;incout10;incout11];
zyearall=[1994*ones(sum(out1),1);1995*ones(sum(out2),1);1996*ones(sum(out3),1);1997*ones(sum(out4),1);1998*ones(sum(out5),1);1999*ones(sum(out6),1);2000*ones(sum(out7),1);2001*ones(sum(out8),1);2002*ones(sum(out9),1);2003*ones(sum(out10),1);2004*ones(sum(out11),1)];
Ztypeall=[wealthall,incall];
decall=[dec1;dec2;dec3;dec4;dec5;dec6;dec7;dec8;dec9;dec10;dec11];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%get 6% of house price for all years.
Fhat=zeros(nobs,T); 
for i = 1:nobs
    yeari = find(year==zyear(i));
    Fhat(i,yeari) = 0.06*price10(i);
    for t=yeari+1:T
        Fhat(i,t) = 0.06*(price10(i)*(totapp(nhood(i),t)/totapp(nhood(i),yeari)));
    end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% if house never sells, change year sold to 999999
tempind = find(fsyear==0);
fsyear(tempind)=999999;

index1 = find(zyear<year(1) & fsyear >= year(1));
index2 = find(zyear<year(2) & fsyear >= year(2));
index3 = find(zyear<year(3) & fsyear >= year(3));
index4 = find(zyear<year(4) & fsyear >= year(4));
index5 = find(zyear<year(5) & fsyear >= year(5));
index6 = find(zyear<year(6) & fsyear >= year(6));
index7 = find(zyear<year(7) & fsyear >= year(7));
index8 = find(zyear<year(8) & fsyear >= year(8));
index9 = find(zyear<year(9) & fsyear >= year(9));
index10 = find(zyear<year(10) & fsyear >= year(10));
index11 = find(zyear<year(11) & fsyear >= year(11));

id2 = [index1; index2; index3 ; index4; index5; index6; index7; index8; index9; index10; index11];

nhood1=nhood(index1);nhood2=nhood(index2);nhood3=nhood(index3);
nhood4=nhood(index4);nhood5=nhood(index5);nhood6=nhood(index6);
nhood7=nhood(index7);nhood8=nhood(index8);nhood9=nhood(index9);
nhood10=nhood(index10);nhood11=nhood(index11);


%code with outside option
%get vectors of move
move2=zeros(length(index2),1);
for i=1:length(index2)
    move2(i) = [year(2) == fsyear(index2(i))];
end
move3=zeros(length(index3),1);
for i=1:length(index3)
    move3(i) = [year(3) == fsyear(index3(i))];
end
move4=zeros(length(index4),1);
for i=1:length(index4)
    move4(i) = [year(4) == fsyear(index4(i))];
end
move5=zeros(length(index5),1);
for i=1:length(index5)
    move5(i) = [year(5) == fsyear(index5(i))];
end
move6=zeros(length(index6),1);
for i=1:length(index6)
    move6(i) = [year(6) == fsyear(index6(i))];
end
move7=zeros(length(index7),1);
for i=1:length(index7)
    move7(i) = [year(7) == fsyear(index7(i))];
end
move8=zeros(length(index8),1);
for i=1:length(index8)
    move8(i) = [year(8) == fsyear(index8(i))];
end
move9=zeros(length(index9),1);
for i=1:length(index9)
    move9(i) = [year(9) == fsyear(index9(i))];
end
move10=zeros(length(index10),1);
for i=1:length(index10)
    move10(i) = [year(10) == fsyear(index10(i))];
end
move11=zeros(length(index11),1);
for i=1:length(index11)
    move11(i) = [year(11) == fsyear(index11(i))];
end

% get total number of move stay decisions
nll = length(index1) + length(index2) + length(index3) + length(index4)...
    +length(index5) + length(index6) + length(index7) + length(index8)...
    +length(index9) + length(index10) +length(index11);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

temp1 = round(Ztype(:,1)); temp1 = min(max(temp1,0),maxw); temp1=temp1+1; %wealth
temp2 = round(Ztype(:,2)); temp2 = min(max(temp2,0),maxi); temp2=temp2+1; %inc

typenumS1 =  M1a*(temp1-1) + temp2; 

temp2 = repmat(temp2,1,11);

temp3 = round(Ws); temp3 = min(max(temp3,0),maxw); temp3 = temp3+1;
temp4 = round(Wm); temp4 = min(max(temp4,0),maxw); temp4 = temp4+1;

typenumbig =  M1a*(temp3-1) + temp2;
typemovenumbig =  M1a*(temp4-1) + temp2;

typenumbigs = typenumbig; typemovenumbigs = typemovenumbig; 

Fhat2=Fhat(index2,2);Fhat3=Fhat(index3,3);Fhat4=Fhat(index4,4);Fhat5=Fhat(index5,5);
Fhat6=Fhat(index6,6);Fhat7=Fhat(index7,7);Fhat8=Fhat(index8,8);Fhat9=Fhat(index9,9);
Fhat10=Fhat(index10,10);Fhat11=Fhat(index11,11);

Ztype2=Ztype(index2,:);Ztype3=Ztype(index3,:);Ztype4=Ztype(index4,:);
Ztype5=Ztype(index5,:);Ztype6=Ztype(index6,:);Ztype7=Ztype(index7,:);
Ztype8=Ztype(index8,:);Ztype9=Ztype(index9,:);Ztype10=Ztype(index10,:);
Ztype11=Ztype(index11,:);

x_sx =  [ones(size(Fhat2))  Ztype2(:,2) 1*ones(size(Fhat2)) Fhat2 Ztype2(:,2).*Fhat2;
    ones(size(Fhat3))  Ztype3(:,2) 2*ones(size(Fhat3)) Fhat3 Ztype3(:,2).*Fhat3;
    ones(size(Fhat4))  Ztype4(:,2) 3*ones(size(Fhat4)) Fhat4 Ztype4(:,2).*Fhat4;
    ones(size(Fhat5))  Ztype5(:,2) 4*ones(size(Fhat5)) Fhat5 Ztype5(:,2).*Fhat5;
    ones(size(Fhat6))  Ztype6(:,2) 5*ones(size(Fhat6)) Fhat6 Ztype6(:,2).*Fhat6;
    ones(size(Fhat7))  Ztype7(:,2) 6*ones(size(Fhat7)) Fhat7 Ztype7(:,2).*Fhat7;
    ones(size(Fhat8))  Ztype8(:,2) 7*ones(size(Fhat8)) Fhat8 Ztype8(:,2).*Fhat8;
    ones(size(Fhat9))  Ztype9(:,2) 8*ones(size(Fhat9)) Fhat9 Ztype9(:,2).*Fhat9;
    ones(size(Fhat10)) Ztype10(:,2) 9*ones(size(Fhat10)) Fhat10 Ztype10(:,2).*Fhat10;
    ones(size(Fhat11)) Ztype11(:,2) 10*ones(size(Fhat11)) Fhat11 Ztype11(:,2).*Fhat11];

y_sx = [move2; move3; move4; move5; move6; move7; move8; move9; move10; move11];

dec_sx = [fsyear(index2)==year(2) & (outside(index2)==1);fsyear(index3)==year(3) & (outside(index3)==1);...
    fsyear(index4)==year(4) & (outside(index4)==1);fsyear(index5)==year(5) & (outside(index5)==1);...
    fsyear(index6)==year(6) & (outside(index6)==1);fsyear(index7)==year(7) & (outside(index7)==1);...
    fsyear(index8)==year(8) & (outside(index8)==1);fsyear(index9)==year(9) & (outside(index9)==1);...
    fsyear(index10)==year(10) & (outside(index10)==1);fsyear(index11)==year(11) & (outside(index11)==1) ];

ztract1dum = zeros(length(ztract1),J); ztract2dum = zeros(length(ztract2),J);
ztract3dum = zeros(length(ztract3),J); ztract4dum = zeros(length(ztract4),J);
ztract5dum = zeros(length(ztract5),J); ztract6dum = zeros(length(ztract6),J);
ztract7dum = zeros(length(ztract7),J); ztract8dum = zeros(length(ztract8),J);
ztract9dum = zeros(length(ztract9),J); ztract10dum = zeros(length(ztract10),J);
ztract11dum = zeros(length(ztract11),J); 

for j=1:J         
    ztract1dum(:,j)= [ztract1==neigh(j) ]; ztract2dum(:,j)= [ztract2==neigh(j) ];
    ztract3dum(:,j)= [ztract3==neigh(j) ]; ztract4dum(:,j)= [ztract4==neigh(j) ];
    ztract5dum(:,j)= [ztract5==neigh(j) ]; ztract6dum(:,j)= [ztract6==neigh(j) ];
    ztract7dum(:,j)= [ztract7==neigh(j) ]; ztract8dum(:,j)= [ztract8==neigh(j) ];
    ztract9dum(:,j)= [ztract9==neigh(j) ]; ztract10dum(:,j)= [ztract10==neigh(j) ];
    ztract11dum(:,j)= [ztract11==neigh(j) ];            
end

%create adaptive bandwidth
density1 = zeros(M1a,T);
density2 = zeros(M2a,T);
for t = 1:T
    indext = find(zyear==t+1993);
    for m1 = 1:M1a
        density1(m1,t) = mean(NKernstd(Ztype(indext,1),m1-1,band));
    end
    for m2 = 1:M2a
        weighta = zeros(length(indext),K);
        density2(m2,t) = mean(NKernstd(Ztype(indext,2),m2-1,band));
    end
end
G1 = geomean(density1); G2 = geomean(density2);

dni1 = (density1./kron(G1,ones(M1a,1))).^(-lambda); dni2 = (density2./kron(G2,ones(M2a,1))).^(-lambda);
dni1 = dni1./kron(min(dni1),ones(M1a,1));  dni2 = dni2./kron(min(dni2),ones(M2a,1));
temp1=[];temp2=[];
for i= 1:M1a
    temp2 = [temp2; dni2];
end
temp1 = kron(dni1,ones(M2a,1));
bandm = zeros(Ma,T,K);
bandm(:,:,1) = band*temp1;
bandm(:,:,2) = band*temp2;

%create weights for inside share estimation
weights1 = zeros(nobs,Ma);
for t = 1:T
    indext = find(zyear==t+1993);
    for m = 1:Ma
        weighta = zeros(length(indext),K);
        for tt=1:K
        weighta(:,tt) = NKernstd(Ztype(indext,tt),Zvalsa(m,tt),bandm(m,t,tt));
        end
    temp = (prod(weighta'))';
    sumK = sum(temp);
    weights1(indext,m) = temp/sumK; 
    end
end

%create weights for outside share estimation 
outweight = zeros(length(decall),Ma);
for m=1:Ma
weighta = zeros(length(decall),K);
for tt=1:K
    weighta(:,tt) = NKernstd(Ztypeall(:,tt),Zvalsa(m,tt),bandm(m,t,tt));
end
outweight(:,m) = (prod(weighta'))';
end

MSa=numtype*Ma;
MSb=numtype*Mb;

zyeart = zyear-1993;


% get outside option parameters
xxx = [ones(size(zyearall)) zyearall-1993];
for m=1:Ma   
    comweight = outweight(:,m);
    bstart =  [1.0516    0.0053]';
    temp = outlogit(decall,xxx,comweight,bstart);
    gamma(:,m)  = temp.beta;
end


S1index1 = find(zyear==year(1)); S1index2 = find(zyear==year(2)); S1index3 = find(zyear==year(3));
S1index4 = find(zyear==year(4)); S1index5 = find(zyear==year(5)); S1index6 = find(zyear==year(6));
S1index7 = find(zyear==year(7)); S1index8 = find(zyear==year(8)); S1index9 = find(zyear==year(9));
S1index10 = find(zyear==year(10)); S1index11 = find(zyear==year(11)); 

% get shares using local weighting of all observations
share = zeros(Ma,J+1,T);

for m=1:Ma
          
    weight1 = weights1(S1index1,m); 
    weight2 = weights1(S1index2,m);
    weight3 = weights1(S1index3,m);
    weight4 = weights1(S1index4,m);
    weight5 = weights1(S1index5,m);
    weight6 = weights1(S1index6,m);
    weight7 = weights1(S1index7,m);
    weight8 = weights1(S1index8,m);
    weight9 = weights1(S1index9,m);
    weight10 = weights1(S1index10,m);
    weight11 = weights1(S1index11,m);     
 
    w1 = sum(weight1);w2 = sum(weight2);w3 = sum(weight3);w4 = sum(weight4);
    w5 = sum(weight5);w6 = sum(weight6);w7 = sum(weight7);w8 = sum(weight8);
    w9 = sum(weight9);w10 = sum(weight10);w11 = sum(weight11);
    
    weight1=weight1/w1; weight2=weight2/w2; weight3=weight3/w3; weight4=weight4/w4;
    weight5=weight5/w5; weight6=weight6/w6; weight7=weight7/w7; weight8=weight8/w8;
    weight9=weight9/w9; weight10=weight10/w10; weight11=weight11/w11;

%Outside option share
for t=1:T
share(m,J+1,t)=exp(gamma(1,m)+gamma(2,m)*t)/(1+exp(gamma(1,m)+gamma(2,m)*t));
end   
          
share(m,1:J,1) = weight1'*ztract1dum;
share(m,1:J,2) = weight2'*ztract2dum;
share(m,1:J,3) = weight3'*ztract3dum;
share(m,1:J,4) = weight4'*ztract4dum;
share(m,1:J,5) = weight5'*ztract5dum;
share(m,1:J,6) = weight6'*ztract6dum;
share(m,1:J,7) = weight7'*ztract7dum;
share(m,1:J,8) = weight8'*ztract8dum;
share(m,1:J,9) = weight9'*ztract9dum;
share(m,1:J,10) = weight10'*ztract10dum;
share(m,1:J,11) = weight11'*ztract11dum;
    
end

share = max(share,1e-10);

temp = (1-share(:,J+1,:))./(sum(share(:,1:J,:),2));
for j = 1:J
share(:,j,:) = (share(:,j,:)).*temp;
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%create index for later use in calling appropriate  values for inside decision
valuetildeindex = zeros(nobs,numtype); denomindex = zeros(nobs,numtype);
for i = 1:nobs
    for h = 1:numtype
    valuetildeindex(i,h) = sub2ind([MSa J+1 T], typenumS1(i) + Ma*(h-1), nhood(i), zyeart(i));
    denomindex(i,h) = sub2ind([MSa T], typenumS1(i) + Ma*(h-1),  zyeart(i));
    end
end


%create index for later use in calling appropriate values for move/stay and outside decisions
evalue = zeros(MSa,J+1,T);
esumvalue = zeros(MSa,T);

indevs2 = zeros(length(index2),numtype); indevm2 = zeros(length(index2),numtype); indevo2 = zeros(length(index2),numtype);
indevs3 = zeros(length(index3),numtype); indevm3 = zeros(length(index3),numtype); indevo3 = zeros(length(index3),numtype);
indevs4 = zeros(length(index4),numtype); indevm4 = zeros(length(index4),numtype); indevo4 = zeros(length(index4),numtype);
indevs5 = zeros(length(index5),numtype); indevm5 = zeros(length(index5),numtype); indevo5 = zeros(length(index5),numtype);
indevs6 = zeros(length(index6),numtype); indevm6 = zeros(length(index6),numtype); indevo6 = zeros(length(index6),numtype);
indevs7 = zeros(length(index7),numtype); indevm7 = zeros(length(index7),numtype); indevo7 = zeros(length(index7),numtype);
indevs8 = zeros(length(index8),numtype); indevm8 = zeros(length(index8),numtype); indevo8 = zeros(length(index8),numtype);
indevs9 = zeros(length(index9),numtype); indevm9 = zeros(length(index9),numtype); indevo9 = zeros(length(index9),numtype);
indevs10 = zeros(length(index10),numtype); indevm10 = zeros(length(index10),numtype); indevo10 = zeros(length(index10),numtype);
indevs11 = zeros(length(index11),numtype); indevm11 = zeros(length(index11),numtype); indevo11 = zeros(length(index11),numtype);

for h = 1:numtype
for i=1:length(index2)    
indevs2(i,h) = sub2ind(size(evalue),typenumbigs(index2(i),2)+ (h-1)*Ma,  nhood2(i),2);
indevm2(i,h) = sub2ind(size(esumvalue),typemovenumbigs(index2(i),2)+ (h-1)*Ma, 2); 
indevo2(i,h) = sub2ind(size(evalue),typemovenumbigs(index2(i),2)+ (h-1)*Ma,  J+1,2); 
end

for i=1:length(index3)    
indevs3(i,h) = sub2ind(size(evalue),typenumbigs(index3(i),3)+ (h-1)*Ma,  nhood3(i),3);
indevm3(i,h) = sub2ind(size(esumvalue),typemovenumbigs(index3(i),3)+ (h-1)*Ma, 3); 
indevo3(i,h) = sub2ind(size(evalue),typemovenumbigs(index3(i),3)+ (h-1)*Ma,  J+1,3); 
end

for i=1:length(index4)    
indevs4(i,h) = sub2ind(size(evalue),typenumbigs(index4(i),4)+ (h-1)*Ma,  nhood4(i),4);
indevm4(i,h) = sub2ind(size(esumvalue),typemovenumbigs(index4(i),4)+ (h-1)*Ma, 4); 
indevo4(i,h) = sub2ind(size(evalue),typemovenumbigs(index4(i),4)+ (h-1)*Ma,  J+1,4); 
end

for i=1:length(index5)    
indevs5(i,h) = sub2ind(size(evalue),typenumbigs(index5(i),5)+ (h-1)*Ma,  nhood5(i),5);
indevm5(i,h) = sub2ind(size(esumvalue),typemovenumbigs(index5(i),5)+ (h-1)*Ma, 5); 
indevo5(i,h) = sub2ind(size(evalue),typemovenumbigs(index5(i),5)+ (h-1)*Ma,  J+1,5); 
end

for i=1:length(index6)    
indevs6(i,h) = sub2ind(size(evalue),typenumbigs(index6(i),6)+ (h-1)*Ma,  nhood6(i),6);
indevm6(i,h) = sub2ind(size(esumvalue),typemovenumbigs(index6(i),6)+ (h-1)*Ma, 6); 
indevo6(i,h) = sub2ind(size(evalue),typemovenumbigs(index6(i),6)+ (h-1)*Ma,  J+1,6); 
end

for i=1:length(index7)    
indevs7(i,h) = sub2ind(size(evalue),typenumbigs(index7(i),7)+ (h-1)*Ma,  nhood7(i),7);
indevm7(i,h) = sub2ind(size(esumvalue),typemovenumbigs(index7(i),7)+ (h-1)*Ma, 7); 
indevo7(i,h) = sub2ind(size(evalue),typemovenumbigs(index7(i),7)+ (h-1)*Ma,  J+1,7); 
end

for i=1:length(index8)    
indevs8(i,h) = sub2ind(size(evalue),typenumbigs(index8(i),8)+ (h-1)*Ma,  nhood8(i),8);
indevm8(i,h) = sub2ind(size(esumvalue),typemovenumbigs(index8(i),8)+ (h-1)*Ma, 8); 
indevo8(i,h) = sub2ind(size(evalue),typemovenumbigs(index8(i),8)+ (h-1)*Ma,  J+1,8); 
end

for i=1:length(index9)    
indevs9(i,h) = sub2ind(size(evalue),typenumbigs(index9(i),9)+ (h-1)*Ma,  nhood9(i),9);
indevm9(i,h) = sub2ind(size(esumvalue),typemovenumbigs(index9(i),9)+ (h-1)*Ma, 9); 
indevo9(i,h) = sub2ind(size(evalue),typemovenumbigs(index9(i),9)+ (h-1)*Ma,  J+1,9); 
end

for i=1:length(index10)    
indevs10(i,h) = sub2ind(size(evalue),typenumbigs(index10(i),10)+ (h-1)*Ma,  nhood10(i),10);
indevm10(i,h) = sub2ind(size(esumvalue),typemovenumbigs(index10(i),10)+ (h-1)*Ma, 10); 
indevo10(i,h) = sub2ind(size(evalue),typemovenumbigs(index10(i),10)+ (h-1)*Ma,  J+1,10); 
end

for i=1:length(index11)    
indevs11(i,h) = sub2ind(size(evalue),typenumbigs(index11(i),11)+ (h-1)*Ma,  nhood11(i),11);
indevm11(i,h) = sub2ind(size(esumvalue),typemovenumbigs(index11(i),11)+ (h-1)*Ma, 11); 
indevo11(i,h) = sub2ind(size(evalue),typemovenumbigs(index11(i),11)+ (h-1)*Ma,  J+1,11); 
end

end

yid2 = [1+0*index1; 2+0*index2; 3+0*index3 ; 4+0*index4; 5+0*index5; 6+0*index6; 7+0*index7; 8+0*index8; 9+0*index9; 10+0*index10; 11+0*index11];
S2vecindex = sub2ind([nobs T], id2,yid2);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

save table1adata income downp price race zyear

clearvars all * -except neigh nhood nobs  valuetildeindex denomindex nll dec_sx y_sx x_sx indev* S2vecindex...
     Ztype Zvalsa Zvalsb  share income ...
  K b2 bb Ma Mb MSa MSb J T totapp incvals nhoodallr ztractallr zyearallr priceallr10 maxw minw maxi mini ...
      indexb vshiftsmall numtype sqft band  mininshare lambda  ...
   typei typej indic neigh_county_map xyear xtract xrace polldata crimedata...

save S1data